package dev.fyloz.musicplayer.core.http

import dev.fyloz.musicplayer.core.getAuthorizationData
import dev.fyloz.musicplayer.core.http.requests.CreateTrackRequest
import dev.fyloz.musicplayer.core.logic.TrackLogic
import io.ktor.server.application.*
import io.ktor.server.request.*
import io.ktor.server.response.*
import io.ktor.server.routing.*
import org.koin.ktor.ext.inject

fun Route.configureTrackRoutes() {
    val logic by inject<TrackLogic>()

    route("/track") {
        get("/") {
            call.respond(logic.getAll().toList())
        }

        get("/search") {
            val query = call.request.queryParameters["q"]!!
            val tracks = logic.search(query, call.getAuthorizationData())
            call.respond(tracks)
        }

        post {
            val request = call.receive<CreateTrackRequest>()
            val track = logic.save(request.type, request.trackId, call.getAuthorizationData())
            call.respond(track)
        }
    }
}
