package dev.fyloz.musicplayer.modules.spotify

import dev.fyloz.musicplayer.modules.spotify.api.SearchRequest
import dev.fyloz.musicplayer.modules.spotify.api.SearchResponse
import dev.fyloz.musicplayer.modules.spotify.api.Track
import io.ktor.client.*
import io.ktor.client.call.*
import io.ktor.client.request.*
import io.ktor.http.*
import org.koin.core.component.KoinComponent
import org.koin.core.component.inject

class SpotifyApiProvider : KoinComponent {
    private val client by inject<HttpClient>()

    suspend fun search(query: String, type: String, accessToken: String): Collection<Track> {
        val requestBody = SearchRequest(query, type, "audio", 50, 0)
        val response = client.get("https://api.spotify.com/v1/search") {
            accept(ContentType.Application.Json)
            headers {
                append(HttpHeaders.Authorization, "Bearer $accessToken")
            }
//            setBody(requestBody)
            url {
                parameters.append("q", query)
                parameters.append("type", type)
                parameters.append("include_external", "audio")
                parameters.append("limit", "50")
                parameters.append("offset", "0")
            }
        }.body<SearchResponse>()

        return response.tracks.items
    }

    suspend fun getTrackById(trackId: String, accessToken: String): Track {
        val response = client.get("https://api.spotify.com/v1/tracks/$trackId") {
            accept(ContentType.Application.Json)
            headers {
                append(HttpHeaders.Authorization, "Bearer $accessToken")
            }
        }

        return response.body()
    }
}
