package dev.fyloz.musicplayer.modules.spotify

import dev.fyloz.musicplayer.core.factory.TrackFactory
import dev.fyloz.musicplayer.core.http.auth.AuthorizationData
import dev.fyloz.musicplayer.core.model.Track

class SpotifyTrackFactory : TrackFactory {
    private val apiProvider = SpotifyApiProvider()

    override suspend fun searchTrack(query: String, auth: AuthorizationData): Collection<Track> {
        val apiTracks = apiProvider.search(query, "track", auth.accessToken)
        return apiTracks.map { SpotifyTrack("not-an-id", it.id, it.name) }
    }

    override suspend fun createTrack(id: String, trackId: String, auth: AuthorizationData): Track {
        val spotifyApiTrack = apiProvider.getTrackById(trackId, auth.accessToken);
        return SpotifyTrack(id, trackId, spotifyApiTrack.name)
    }

    private val AuthorizationData.accessToken
        get() = getModuleData<SpotifyAuthorizationData>(SpotifyModule.moduleName).accessToken
}
